@@ -267,12 +267,15 @@ class Zones(ScanFrame):
     def __init__(self, osef_frame: dict):
         """Constructor."""
         super().__init__(osef_frame)
-        for key in [
-            types.OsefKeys.ZONES_DEF.value,
-            types.OsefKeys.ZONES_OBJECTS_BINDING_32_BITS.value,
-        ]:
-            if key not in self._scan_frame:
-                raise ValueError(f"{key} missing in scan_frame")
+
+        if types.OsefKeys.ZONES_DEF.value not in self._scan_frame:
+            raise ValueError(f"{types.OsefKeys.ZONES_DEF.value} missing in scan_frame")
+
+        if (
+            types.OsefKeys.ZONES_OBJECTS_BINDING_32_BITS.value not in self._scan_frame
+            and types.OsefKeys.ZONES_OBJECTS_BINDING.value not in self._scan_frame
+        ):
+            raise ValueError(f"Zone bindings missing in scan_frame")
 
         self._zones_def = self._scan_frame.get(types.OsefKeys.ZONES_DEF.value)
         self._zones_binding = self._scan_frame.get(
